@@ -1,9 +1,12 @@
 import datetime
+import logging
 
 from httpx import AsyncClient
 
 from wolf_smartset import constants
 
+_LOGGER = logging.getLogger(__name__)
+
 
 class Tokens:
     """Has two tokens: access and refresh"""
@@ -31,6 +34,7 @@ class TokenAuth:
 
         resp = await session.post(constants.BASE_URL + "/connect/token2", data=data)
         json = resp.json()
+        _LOGGER.debug('Token response: %s', json)
         if "error" in json:
             raise InvalidAuth
         return Tokens(json.get("access_token"), json.get("refresh_token"), json.get("expires_in"))
